@@ -5,7 +5,7 @@ class Client:
     def __make_request(self, path):
         res = request('GET', f'https://jsonplaceholder.typicode.com/{path}')
 
-        if (res.status_code >= 400 or 'json' in res.headers.get('Content-Type','')) and self.__handle_errors:
+        if (res.status_code >= 400 or 'json' not in res.headers.get('Content-Type','')) and self.__handle_errors:
             raise Exception
 
         return res.json()
